@@ -36,7 +36,7 @@ class SOVFixerAPIClient(APIClientBase):
         client_ref=None,
         integrations=None,
         extra_data=None,
-        delegate_to: str | None = None,
+        delegate_to_team: str | None = None,
         update_callback_url=None,
         allow_ping_data_api=None,
         workflow=None,
@@ -69,8 +69,8 @@ class SOVFixerAPIClient(APIClientBase):
         if extra_data is not None:
             for k, v in extra_data.items():
                 data["extra_data_" + k] = v
-        if delegate_to is not None:
-            data["delegate_to"] = delegate_to
+        if delegate_to_team is not None:
+            data["delegate_to_team"] = delegate_to_team
         if allow_ping_data_api is not None:
             data["allow_ping_data_api"] = allow_ping_data_api
         if workflow is not None:
@@ -173,8 +173,15 @@ class SOVFixerAPIClient(APIClientBase):
 
     def activity_download(self, output_ret, actually_write=False, output_path=None):
         output_url = output_ret["url"]
-        is_input_ret = "label" not in output_ret
-        if is_input_ret:
+        is_update_output_ret = "filename" not in output_ret and "scrubbed_filename" not in output_ret
+        is_input_ret = "label" not in output_ret and not is_update_output_ret
+
+        # this is old and will go away...
+        if is_update_output_ret:
+            output_description = "Update"
+            output_filename = output_url.split("/")[-1]
+
+        elif is_input_ret:
             output_description = "Input"
             output_filename = output_ret["filename"]
         else:
@@ -183,12 +190,16 @@ class SOVFixerAPIClient(APIClientBase):
         if output_path is None:
             output_path = output_filename
 
-        return self.download_file(
-            output_url,
-            output_path,
-            actually_write=actually_write,
-            output_description=output_description,
-        )
+        try:
+            return self.download_file(
+                output_url,
+                output_path,
+                actually_write=actually_write,
+                output_description=output_description,
+            )
+        except Exception as e:
+            self.logger.warning(f"Error downloading {output_description} output: {e}")
+            return None
 
     def fix_sov(
         self,
@@ -202,7 +213,7 @@ class SOVFixerAPIClient(APIClientBase):
         client_ref=None,
         extra_data=None,
         update_callback_url=None,
-        delegate_to=None,
+        delegate_to_team=None,
         noinput=True,
         allow_ping_data_api=True,
         workflow=None,
@@ -217,7 +228,7 @@ class SOVFixerAPIClient(APIClientBase):
             client_ref=client_ref,
             extra_data=extra_data,
             update_callback_url=update_callback_url,
-            delegate_to=delegate_to,
+            delegate_to_team=delegate_to_team,
             allow_ping_data_api=allow_ping_data_api,
             workflow=workflow,
         )
@@ -415,6 +426,7 @@ class SOVFixerAPIClient(APIClientBase):
         policy_terms=None,
         policy_terms_format_name=None,
         output_formats=None,
+        metadata=None,
     ):
         url = self.api_url + f"/api/v1/sov/update/{sudid}/start"
         data = {}
@@ -426,6 +438,8 @@ class SOVFixerAPIClient(APIClientBase):
             data["policy_terms_format_name"] = policy_terms_format_name
         if output_formats:
             data["output_formats"] = output_formats
+        if metadata:
+            data["metadata"] = metadata
 
         response = self.post(url, json=data)
         if 200 <= response.status_code < 300:
@@ -461,6 +475,7 @@ class SOVFixerAPIClient(APIClientBase):
         update_type=None,
         callback_url=None,
         noinput=True,
+        metadata=None,
     ):
         client = self
         init_response = client.update_sov_async_init(sovid, update_type=update_type, callback_url=callback_url)
@@ -477,6 +492,7 @@ class SOVFixerAPIClient(APIClientBase):
             policy_terms=policy_terms,
             policy_terms_format_name=policy_terms_format_name,
             output_formats=output_formats,
+            metadata=metadata,
         )
 
         while 1:
@@ -524,7 +540,7 @@ class SOVFixerAPIClient(APIClientBase):
             return False
 
     def get_or_create_output_async_start(
-        self, sovid_or_sud: str, output_format: str, revision: int = -1, overwrite_existing=False
+        self, sovid_or_sud: str, output_format: str, revision: int = -1, overwrite_existing: bool=False, delegate_to_team: str | None = None,
     ):
         url = self.api_url + f"/api/v1/sov/{sovid_or_sud}/get_or_create_output"
         data = {}
@@ -534,6 +550,8 @@ class SOVFixerAPIClient(APIClientBase):
             data["revision"] = revision
         if overwrite_existing:
             data["overwrite_existing"] = overwrite_existing
+        if delegate_to_team is not None:
+            data["delegate_to_team"] = delegate_to_team
 
         response = self.post(url, data=data)
         raise_for_status(response)
@@ -551,13 +569,14 @@ class SOVFixerAPIClient(APIClientBase):
         revision: int = -1,
         overwrite_existing=False,
         timeout: timedelta | None = timedelta(minutes=5),
+        delegate_to_team: str | None = None,
     ) -> t.OutputData:
         """Synchronously get or create an output from a SOV Fixer request. If it exists, it will return immediately.
         If it does not exist, it will start the generation process and poll for completion, then return it."""
         client = self
 
         start_response = client.get_or_create_output_async_start(
-            sovid_or_sud, output_format, revision, overwrite_existing
+            sovid_or_sud, output_format, revision, overwrite_existing, delegate_to_team,
         )
 
         output_request_id = start_response["request"]["id"]
@@ -586,7 +605,7 @@ class SOVFixerAPIClient(APIClientBase):
             scrubbed_filename=result.get("scrubbed_filename", None),
             output_format=result.get("output_format", None),
             url=result.get("url", None),
-            ping_ready_id=result.get("ping_ready_id", None),
+            ping_certified_id=result.get("ping_certified_id", None),
         )
         return output
 
@@ -604,4 +623,4 @@ class SOVFixerAPIClient(APIClientBase):
         raise_for_status(response)
 
         response_data = response.json()
-        return response_data
\ No newline at end of file
+        return response_data
